summaryrefslogtreecommitdiff
path: root/lisp/erc/erc-notify.el
diff options
context:
space:
mode:
authorJuanma Barranquero <lekktu@gmail.com>2011-11-14 22:00:24 +0100
committerJuanma Barranquero <lekktu@gmail.com>2011-11-14 22:00:24 +0100
commit0b381c7eb83c635f39159168a48c869d632d8081 (patch)
tree32ad79519ce958dc2dbcdcd357d37d652314edb1 /lisp/erc/erc-notify.el
parent8350f087efe62e2ce0ded434534629a56cdc4e8c (diff)
downloademacs-0b381c7eb83c635f39159168a48c869d632d8081.tar.gz
Fix typos.
Diffstat (limited to 'lisp/erc/erc-notify.el')
-rw-r--r--lisp/erc/erc-notify.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/lisp/erc/erc-notify.el b/lisp/erc/erc-notify.el
index 7ae15307a55..10f6806ec12 100644
--- a/lisp/erc/erc-notify.el
+++ b/lisp/erc/erc-notify.el
@@ -46,7 +46,7 @@ status change."
:type '(repeat string))
(defcustom erc-notify-interval 60
- "*Time interval (in seconds) for checking online status of notificated
+ "*Time interval (in seconds) for checking online status of notified
people."
:group 'erc-notify
:type 'integer)
@@ -197,11 +197,11 @@ nick from `erc-last-ison' to prevent any further notifications."
;;;###autoload
(defun erc-cmd-NOTIFY (&rest args)
"Change `erc-notify-list' or list current notify-list members online.
-Without args, list the current list of notificated people online,
+Without args, list the current list of notified people online,
with args, toggle notify status of people."
(cond
((null args)
;; Print current notificated people (online)
(let ((ison (erc-with-server-buffer erc-last-ison)))
(if (not ison)
(erc-display-message
@@ -197,11 +197,11 @@ nick from `erc-last-ison' to prevent any further notifications."
(cond
((null args)
- ;; Print current notificated people (online)
+ ;; Print current notified people (online)
(let ((ison (erc-with-server-buffer erc-last-ison)))
(if (not ison)